(* VEC Reader - reads VEC vector graphic files and displays them on the screen. *)
(* Version 1.0 *)
program VecReader;
(*$IKERNEL2.INC*)
(*$IGRAPHLB2.INC*)
(*$IINPUT.INC*)
(*$IBOX.INC*)
(*$IVECIN.INC*)

label
  byebye;
var
  FileName: string(.14.);
  err:      ErrorCode;
  opCode:   byte;
  count:    byte;
  x1:       integer;
  y1:       integer;
  x2:       integer;
  y2:       integer;
  mode:     byte;

(* Main program *)
begin
  ClrScr;
  
  (* get the name of the VEC file *)
  if ParamCount > 0 then begin
    FileName := ParamStr(1); (* first commandline parameter treated as filename *)
  end
  else begin
    DrawBox(1, 1, 90, 3);
    GotoXY(28, 2);
    Write('VEC file reader V1.1 by Bernd Bock');
    DrawBox(1, 4, 90, 3);
    GotoXY(3, 5);
    Write('Enter name of VEC file: ');
    FileName := InputFileName;
    GotoXY(1, 7);
    if Length(FileName) = 0 then goto byebye; (* abort if no filename entered *)
  end;
  
  ClrScr;
  GraphInit;
  HideCursor;
  mode := 0;

  if OpenVecFile(FileName) = ErrOk then begin
    if ReadVecHeader then begin
      repeat
        opCode := ReadOpCode;
        if (opCode > 9) and (opCode < 99) then begin
          count := ReadDotCount;
        end;
        case opCode of
           0: (* Dot *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              Plot(x1, y1, mode);
              end;
           1: (* Line         *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              x2 := ReadValue;
              y2 := ReadValue;
              Line(x1, y1, x2, y2, mode);
              end;
           2: (* Box          *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              x2 := ReadValue;
              y2 := ReadValue;
              Box(x1, y1, x2, y2, mode);
              end;
           3: (* Square       *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              x2 := ReadValue; (* width *)
              Square(x1, y1, x2, mode);
              end;
           4: (* Ellipse      *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              x2 := ReadValue; (* radius x *)
              y2 := ReadValue; (* radius y *)
              Ellipse(x1, y1, x2, y2, mode);
              end;
           5: (* Circle       *) begin
              x1 := ReadValue;
              y1 := ReadValue;
              x2 := ReadValue; (* radius *)
              Circle(x1, y1, x2, mode);
              end;
          10: (* Multi-Dot    *) begin
              end;
          11: (* Multi-Line   *) begin
              end;
          12: (* Polygon-Fill *) begin
              end;
          99: (* End *) begin
              end;
          else WriteLn('Unknown OpCode: ', opCode);
        end;
      until opCode = 99;
    end
    else begin
      WriteLn('File ', FileName, ' is not a VEC file.');
    end;
    CloseVecFile;
    end
  else
    WriteLn('Could not open ', FileName);
  
  Beep;
  WaitForKey;
  
byebye:  
  ShowCursor;
end.
